@@ -1,5 +1,3 @@
-"""ramalama common module."""
-
 from __future__ import annotations
 
 import glob
@@ -13,9 +11,9 @@ import shutil
 import string
 import subprocess
 import sys
-from collections.abc import Callable
+from collections.abc import Callable, Sequence
 from functools import lru_cache
-from typing import TYPE_CHECKING, Literal, Protocol, TypeAlias, TypedDict, cast, get_args
+from typing import IO, TYPE_CHECKING, Any, Literal, Optional, Protocol, TypeAlias, TypedDict, cast, get_args
 
 import yaml
 
@@ -133,7 +131,15 @@ def exec_cmd(args, stdout2null: bool = False, stderr2null: bool = False):
         raise
 
 
-def run_cmd(args, cwd=None, stdout=subprocess.PIPE, ignore_stderr=False, ignore_all=False, encoding=None, env=None):
+def run_cmd(
+    args: Sequence[str],
+    cwd: str | None = None,
+    stdout: int | IO[Any] | None = subprocess.PIPE,
+    ignore_stderr: bool = False,
+    ignore_all: bool = False,
+    encoding: str | None = None,
+    env: dict[str, str] | None = None,
+) -> subprocess.CompletedProcess[Any]:
     """
     Run the given command arguments.
 
@@ -522,6 +528,7 @@ def check_mthreads() -> Literal["musa"] | None:
 AccelType: TypeAlias = Literal["asahi", "cuda", "cann", "hip", "intel", "musa"]
 
 
+@lru_cache(maxsize=1)
 def get_accel() -> AccelType | Literal["none"]:
     checks: tuple[Callable[[], AccelType | None], ...] = (
         check_asahi,
@@ -600,6 +607,7 @@ def tagged_image(image: str) -> str:
     return f"{image}:{minor_release()}"
 
 
+@lru_cache(maxsize=1)
 def check_cuda_version() -> tuple[int, int]:
     """
     Check the CUDA version installed on the system by parsing the output of nvidia-smi --version.
@@ -755,3 +763,14 @@ def attempt_to_use_versioned(conman: str, image: str, vers: str, quiet: bool, sh
 
     except Exception:
         return False
+
+
+class ContainerEntryPoint(str):
+    def __init__(self, entrypoint: Optional[str] = None):
+        self.entrypoint = entrypoint
+
+    def __str__(self):
+        return str(self.entrypoint)
+
+    def __repr__(self):
+        return repr(self.entrypoint)
