@@ -5,25 +5,29 @@ import subprocess
 import sys
 import time
 from abc import ABC, abstractmethod
+from collections.abc import Callable, Sequence
 from http.client import HTTPConnection, HTTPException
-from typing import Any, Callable
+from typing import Any
 
 # Live reference for checking global vars
 import ramalama.common
+from ramalama.arg_types import BaseEngineArgsType
 from ramalama.common import check_nvidia, exec_cmd, get_accel_env_vars, perror, run_cmd
 from ramalama.compat import NamedTemporaryFile
+from ramalama.config import get_config
 from ramalama.logger import logger
+from ramalama.path_utils import normalize_host_path_for_container
 
 
 class BaseEngine(ABC):
     """General-purpose engine for running podman or docker commands"""
 
-    def __init__(self, args):
+    def __init__(self, args: BaseEngineArgsType) -> None:
         base = os.path.basename(args.engine)
-        self.use_docker = base == "docker"
-        self.use_podman = base == "podman"
+        self.use_docker: bool = base == "docker"
+        self.use_podman: bool = base == "podman"
         self.args = args
-        self.exec_args = [self.args.engine]
+        self.exec_args: list[str] = [self.args.engine]
         self.base_args()
         self.add_labels()
         self.add_network()
@@ -35,10 +39,10 @@ class BaseEngine(ABC):
     @abstractmethod
     def base_args(self): ...
 
-    def add_label(self, label):
+    def add_label(self, label: str):
         self.add(["--label", label])
 
-    def add_name(self, name):
+    def add_name(self, name: str):
         self.add(["--name", name])
 
     def add_labels(self):
@@ -112,14 +116,14 @@ class BaseEngine(ABC):
         if getattr(self.args, "podman_keep_groups", None):
             self.exec_args += ["--group-add", "keep-groups"]
 
-    def add(self, newargs):
-        self.exec_args += newargs
+    def add(self, newargs: Sequence[str]):
+        self.exec_args.extend(newargs)
 
     def add_args(self, *args: str) -> None:
         self.add(args)
 
     def add_volume(self, src: str, dest: str, *, opts="ro"):
-        self.add_args("-v", f"{src}:{dest}:{opts}{self.relabel()}")
+        self.add_args("-v", f"{normalize_host_path_for_container(src)}:{dest}:{opts}{self.relabel()}")
 
     def dryrun(self):
         dry_run(self.exec_args)
@@ -143,7 +147,7 @@ class BaseEngine(ABC):
 class Engine(BaseEngine):
     """Engine for executing 'podman run'"""
 
-    def __init__(self, args):
+    def __init__(self, args: BaseEngineArgsType) -> None:
         super().__init__(args)
         self.add_detach_option()
         self.add_device_options()
@@ -174,15 +178,18 @@ class Engine(BaseEngine):
             self.add_env_option(env)
 
     def add_port_option(self) -> None:
-        if getattr(self.args, "port", "") == "":
+        port = getattr(self.args, "port", "")
+        if not port:
             return
 
+        # Convert port to string for processing
+        port_str = str(port)
         host = getattr(self.args, "host", "0.0.0.0")
         host = f"{host}:" if host != "0.0.0.0" else ""
-        if self.args.port.count(":") > 0:
-            self.add_args("-p", f"{host}{self.args.port}")
+        if ":" in port_str:
+            self.add_args("-p", f"{host}{port_str}")
         else:
-            self.add_args("-p", f"{host}{self.args.port}:{self.args.port}")
+            self.add_args("-p", f"{host}{port_str}:{port_str}")
 
     def add_privileged_options(self) -> None:
         if getattr(self.args, "privileged", False):
@@ -319,7 +326,7 @@ def containers(args):
         raise (e)
 
 
-def info(args):
+def info(args) -> list[Any] | str | dict[str, Any]:
     conman = str(args.engine) if args.engine is not None else None
     if conman == "" or conman is None:
         raise ValueError("no container manager (Podman, Docker) found")
@@ -334,7 +341,7 @@ def info(args):
         return str(e)
 
 
-def inspect(args, name, format=None, ignore_stderr=False):
+def inspect(args, name: str, format: str | None = None, ignore_stderr: bool = False):
     if not name:
         raise ValueError("must specify a container name")
     conman = str(args.engine) if args.engine is not None else None
@@ -349,7 +356,7 @@ def inspect(args, name, format=None, ignore_stderr=False):
     return run_cmd(conman_args, ignore_stderr=ignore_stderr).stdout.decode("utf-8").strip()
 
 
-def logs(args, name, ignore_stderr=False):
+def logs(args, name: str, ignore_stderr: bool = False):
     if not name:
         raise ValueError("must specify a container name")
     conman = str(args.engine) if args.engine is not None else None
@@ -360,7 +367,7 @@ def logs(args, name, ignore_stderr=False):
     return run_cmd(conman_args, ignore_stderr=ignore_stderr).stdout.decode("utf-8").strip()
 
 
-def stop_container(args, name, remove=False):
+def stop_container(args, name: str, remove: bool = False):
     if not name:
         raise ValueError("must specify a container name")
     conman = str(args.engine) if args.engine is not None else None
@@ -416,7 +423,7 @@ def stop_container(args, name, remove=False):
                 raise
 
 
-def add_labels(args, add_label):
+def add_labels(args, add_label: Callable[[str], None]):
     label_map = {
         "MODEL": "ai.ramalama.model",
         "engine": "ai.ramalama.engine",
@@ -432,30 +439,44 @@ def add_labels(args, add_label):
 def is_healthy(args, timeout: int = 3, model_name: str | None = None):
     """Check if the response from the container indicates a healthy status."""
     conn = None
+    config = get_config()
     try:
         conn = HTTPConnection("127.0.0.1", args.port, timeout=timeout)
-        if args.debug:
+        if getattr(args, "debug", False):
             conn.set_debuglevel(1)
-        conn.request("GET", "/models")
-        resp = conn.getresponse()
-        if resp.status != 200:
-            logger.debug(f"Container {args.name} returned status code {resp.status}: {resp.reason}")
+        if config.runtime == 'vllm':
+            conn.request("GET", "/ping")
+            vllm_ping_resp = conn.getresponse()
+            return vllm_ping_resp.status == 200
+        conn.request("GET", "/health")
+        health_resp = conn.getresponse()
+        health_resp.read()
+        if health_resp.status not in (200, 404):
+            logger.debug(f"Container {args.name} /health status code: {health_resp.status}: {health_resp.reason}")
             return False
-        content = resp.read()
+        conn.request("GET", "/models")
+        models_resp = conn.getresponse()
+        if models_resp.status != 200:
+            logger.debug(f"Container {args.name} /models status code {models_resp.status}: {models_resp.reason}")
+            return False
+        content = models_resp.read()
         if not content:
-            logger.debug(f"Container {args.name} returned an empty response")
+            logger.debug(f"Container {args.name} /models returned an empty response")
             return False
         body = json.loads(content)
         if "models" not in body:
-            logger.debug(f"Container {args.name} does not include a model list in the response")
+            logger.debug(f"Container {args.name} /models does not include a model list in the response")
             return False
         model_names = [m["name"] for m in body["models"]]
         if not model_name:
-            # The transport and tag is not included in the model name returned by the endpoint
-            model_name = args.MODEL.split("://")[-1]
-            model_name = model_name.split(":")[0]
+            # FIXME: modules have a circular dependency so inline import here
+            from ramalama.transports.transport_factory import New
+
+            model_name = New(args.MODEL, args).model_alias
         if not any(model_name in name for name in model_names):
-            logger.debug(f'Container {args.name} does not include "{model_name}" in the model list: {model_names}')
+            logger.debug(
+                f'Container {args.name} /models does not include "{model_name}" in the model list: {model_names}'
+            )
             return False
         logger.debug(f"Container {args.name} is healthy")
         return True
@@ -464,17 +485,27 @@ def is_healthy(args, timeout: int = 3, model_name: str | None = None):
             conn.close()
 
 
-def wait_for_healthy(args, health_func: Callable[[Any], bool], timeout=20):
+def wait_for_healthy(args, health_func: Callable[[Any], bool], timeout=None):
     """Waits for a container to become healthy by polling its endpoint."""
+    config = get_config()
+    if timeout is None:
+        timeout = 180 if config.runtime == "vllm" else 20
     logger.debug(f"Waiting for container {args.name} to become healthy (timeout: {timeout}s)...")
     start_time = time.time()
 
+    display_dots = not getattr(args, "debug", False) and sys.stdin.isatty()
+    n = 0
     while time.time() - start_time < timeout:
         try:
+            if display_dots:
+                perror('\r' + n * '.', end='', flush=True)
             if health_func(args):
+                if display_dots:
+                    perror('\r' + n * ' ' + '\r', end='', flush=True)
                 return
         except (ConnectionError, HTTPException, UnicodeDecodeError, json.JSONDecodeError) as e:
             logger.debug(f"Health check of container {args.name} failed, retrying... Error: {e}")
+            n += 1
         time.sleep(1)
 
     raise subprocess.TimeoutExpired(
